@@ -279,7 +279,10 @@ class Rows:
     def update(self, **kwargs):
         def updatefn(r):
             for k, v in kwargs.items():
-                r.update({k: v(r)})
+                if callable(v):
+                    r.update({k: v(r)})
+                else:
+                    r.update({k: v})
             yield r
 
         return self.apply(updatefn)
@@ -304,22 +307,27 @@ class Rows:
             ds = Rows(rs)
             r = {}
             for k, fn in kwargs.items():
-                r[k] = fn(ds)
+                if callable(fn):
+                    r[k] = fn(ds)
+                else:
+                    r[k] = fn
             yield r
 
         def foldfn2(keys, rs):
             ds = Rows(rs)
             r = dict(zip(gcols, keys))
             for k, fn in kwargs.items():
-                r[k] = fn(ds)
+                if callable(fn):
+                    r[k] = fn(ds)
+                else:
+                    r[k] = fn
             yield r
 
         if self._insts[-1]['cmd'] == 'windowed':
             return self.apply(foldfn1)
-        elif self._insts[-1]['cmd'] == 'group':
+        if self._insts[-1]['cmd'] == 'group':
             return self.apply(foldfn2)
-        else:
-            raise ValueError("fold must be preceded by grouping processes")
+        raise ValueError("fold must be preceded by grouping processes")
 
     def select(self, *cols):
         def selectfn(r):
