@@ -36,6 +36,23 @@ class TestCore(unittest.TestCase):
         if Path(self.dbfile1).is_file():
             os.remove(self.dbfile1)
 
+    def test_do_later(self):
+        conn = Conn(self.dbfile)
+        conn['t1'] = self.t1
+
+        xs, ys = conn['t1'].tee(2)
+        xs.by('col1')
+        tot = sum(ys['col2'])
+        xs.fold(
+            col3=lambda rs: sum(rs['col2']),
+            col4=tot
+        )
+        self.assertEqual(xs.list(),
+                         [{'col1': 'a', 'col3': 9, 'col4': 26},
+                          {'col1': 'b', 'col3': 1, 'col4': 26},
+                          {'col1': 'c', 'col3': 14, 'col4': 26},
+                          {'col1': 'd', 'col3': 2, 'col4': 26}])
+
     def test_zip(self):
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
@@ -151,7 +168,7 @@ class TestCore(unittest.TestCase):
             def innerfn(rs):
                 nonlocal n
                 n += 1
-                return rs.update(n=lambda r: n)
+                return rs.update(n=n)
             return innerfn
 
         conn['t1_1'] = conn['t1'].by('col1').map(cnt())
@@ -212,7 +229,7 @@ class TestCore(unittest.TestCase):
     def test_by(self):
         def sum_by_col1(rs):
             tot = sum(rs['col2'])
-            return rs.update(col2=lambda r: tot).islice(1)
+            return rs.update(col2=tot).islice(1)
 
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
@@ -252,11 +269,11 @@ class TestCore(unittest.TestCase):
     def test_by_after_map(self):
         def sumit(rs):
             tot = sum(rs['col2'])
-            return rs.update(tot=lambda r: tot)
+            return rs.update(tot=tot)
 
         def count(rs):
             n = len(rs.list())
-            return rs.update(cnt=lambda r: n)
+            return rs.update(cnt=n)
 
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
@@ -276,15 +293,14 @@ class TestCore(unittest.TestCase):
 
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
-        conn['t1_1'] = conn['t1'].update(col3=lambda r: 1).by('col1', 'col3')\
+        conn['t1_1'] = conn['t1'].update(col3=1).by('col1', 'col3')\
             .map(lambda rs: rs)
 
-        conn['t1_2'] = conn['t1'].update(
-            col3=lambda r: 1).by('col1').map(lambda rs: rs)
+        conn['t1_2'] = conn['t1'].update(col3=1).by('col1').map(lambda rs: rs)
         self.assertEqual(conn['t1_1'].list(), conn['t1_2'].list())
 
         conn['t1_1_double'] = conn['t1_1']\
-            .chain(conn['t1'].update(col3=lambda r: 1).by('col1', 'col3')
+            .chain(conn['t1'].update(col3=1).by('col1', 'col3')
                    .map(lambda rs: rs))
         conn['t1_1_double2'] = conn['t1_1'].chain(conn['t1_1'])
 
